@@ -1,8 +1,26 @@
-{-# LANGUAGE QuasiQuotes, TypeFamilies #-}
-{-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE FlexibleContexts #-}
-{-# LANGUAGE PatternGuards #-}
-{-# LANGUAGE Rank2Types #-}
+{-# LANGUAGE ConstrainedClassMethods #-}
+{-# LANGUAGE FlexibleContexts        #-}
+{-# LANGUAGE OverloadedStrings       #-}
+{-# LANGUAGE PatternGuards           #-}
+{-# LANGUAGE QuasiQuotes             #-}
+{-# LANGUAGE Rank2Types              #-}
+{-# LANGUAGE TypeFamilies            #-}
+-- | A Yesod plugin for Authentication via e-mail
+--
+-- This plugin works out of the box by only setting a few methods on the type class
+-- that tell the plugin how to interoprate with your user data storage (your database).
+-- However, almost everything is customizeable by setting more methods on the type class.
+-- In addition, you can send all the form submissions via JSON and completely control the user's flow.
+-- This is a standard registration e-mail flow
+--
+-- 1) A user registers a new e-mail address, and an e-mail is sent there
+-- 2) The user clicks on the registration link in the e-mail
+--    Note that at this point they are actually logged in (without a password)
+--    That means that when they log out they will need to reset their password
+-- 3) The user sets their password and is redirected to the site.
+-- 4) The user can now
+--    * logout and sign in
+--    * reset their password
 module Yesod.Auth.Email
     ( -- * Plugin
       authEmail
@@ -14,6 +32,7 @@ module Yesod.Auth.Email
     , registerR
     , forgotPasswordR
     , setpassR
+    , verifyR
     , isValidPass
       -- * Types
     , Email
@@ -31,28 +50,27 @@ module Yesod.Auth.Email
     , defaultSetPasswordHandler
     ) where
 
-import Network.Mail.Mime (randomString)
-import Yesod.Auth
-import System.Random
-import qualified Data.Text as TS
-import qualified Data.Text as T
-import qualified Data.Text.Lazy as TL
-import qualified Data.Text.Encoding as TE
-import qualified Data.Text.Lazy.Encoding as TLE
-import qualified Crypto.Hash.MD5 as H
-import Data.ByteString.Base16 as B16
-import Data.Text.Encoding (encodeUtf8, decodeUtf8With)
-import Data.Text.Encoding.Error (lenientDecode)
-import Data.Text (Text)
-import Yesod.Core
-import qualified Yesod.PasswordStore as PS
+import           Yesod.Auth
+import qualified Yesod.Auth.Message       as Msg
+import           Yesod.Core
+import           Yesod.Form
+import qualified Yesod.PasswordStore      as PS
+
+import           Control.Applicative      ((<$>), (<*>))
+import qualified Crypto.Hash.MD5          as H
+import qualified Crypto.Nonce             as Nonce
+import           Data.ByteString.Base16   as B16
+import           Data.Text                (Text)
+import qualified Data.Text                as TS
+import qualified Data.Text                as T
+import           Data.Text.Encoding       (decodeUtf8With, encodeUtf8)
+import qualified Data.Text.Encoding       as TE
+import           Data.Text.Encoding.Error (lenientDecode)
+import           Data.Time                (addUTCTime, getCurrentTime)
+import           Safe                     (readMay)
+import           System.IO.Unsafe         (unsafePerformIO)
 import qualified Text.Email.Validate
-import qualified Yesod.Auth.Message as Msg
-import Control.Applicative ((<$>), (<*>))
-import Control.Monad (void)
-import Yesod.Form
-import Data.Time (getCurrentTime, addUTCTime)
-import Safe (readMay)
+
 
 loginR, registerR, forgotPasswordR, setpassR :: AuthRoute
 loginR = PluginR "email" ["login"]
@@ -60,8 +78,11 @@ registerR = PluginR "email" ["register"]
 forgotPasswordR = PluginR "email" ["forgot-password"]
 setpassR = PluginR "email" ["set-password"]
 
-verify :: Text -> Text -> AuthRoute -- FIXME
-verify eid verkey = PluginR "email" ["verify", eid, verkey]
+-- |
+--
+-- Since 1.4.5
+verifyR :: Text -> Text -> AuthRoute -- FIXME
+verifyR eid verkey = PluginR "email" ["verify", eid, verkey]
 
 type Email = Text
 type VerKey = Text
@@ -79,11 +100,11 @@ type Identifier = Text
 
 -- | Data stored in a database for each e-mail address.
 data EmailCreds site = EmailCreds
-    { emailCredsId :: AuthEmailId site
+    { emailCredsId     :: AuthEmailId site
     , emailCredsAuthId :: Maybe (AuthId site)
     , emailCredsStatus :: VerStatus
     , emailCredsVerkey :: Maybe VerKey
-    , emailCredsEmail :: Email
+    , emailCredsEmail  :: Email
     }
 
 class ( YesodAuth site
@@ -144,9 +165,7 @@ class ( YesodAuth site
     --
     -- Since 1.1.0
     randomKey :: site -> IO Text
-    randomKey _ = do
-        stdgen <- newStdGen
-        return $ TS.pack $ fst $ randomString 10 stdgen
+    randomKey _ = Nonce.nonce128urlT defaultNonceGen
 
     -- | Route to send user to after password has been set correctly.
     --
@@ -182,7 +201,9 @@ class ( YesodAuth site
     confirmationEmailSentResponse :: Text -> HandlerT site IO TypedContent
     confirmationEmailSentResponse identifier = do
         mr <- getMessageRender
-        messageJson401 (mr msg) $ authLayout $ do
+        selectRep $ do
+            provideJsonMessage (mr msg)
+            provideRep $ authLayout $ do
               setTitleI Msg.ConfirmationEmailSentTitle
               [whamlet|<p>_{msg}|]
       where
@@ -243,11 +264,11 @@ $newline never
         <tr>
             <th>_{Msg.Email}
             <td>
-                <input type="email" name="email">
+                <input type="email" name="email" required>
         <tr>
             <th>_{Msg.Password}
             <td>
-                <input type="password" name="password">
+                <input type="password" name="password" required>
         <tr>
             <td colspan="2">
                 <button type=submit .btn .btn-success>
@@ -329,7 +350,7 @@ registerHelper allowUsername dest = do
                 Nothing -> loginErrorMessageI dest (Msg.IdentifierNotFound identifier)
                 Just (lid, verKey, email) -> do
                     render <- getUrlRender
-                    let verUrl = render $ verify (toPathPiece lid) verKey
+                    let verUrl = render $ verifyR (toPathPiece lid) verKey
                     lift $ sendVerifyEmail email verKey verUrl
                     lift $ confirmationEmailSentResponse identifier
 
@@ -565,3 +586,8 @@ setLoginLinkKey :: (YesodAuthEmail site, MonadHandler m, HandlerSite m ~ site) =
 setLoginLinkKey aid = do
     now <- liftIO getCurrentTime
     setSession loginLinkKey $ TS.pack $ show (toPathPiece aid, now)
+
+
+defaultNonceGen :: Nonce.Generator
+defaultNonceGen = unsafePerformIO (Nonce.new)
+{-# NOINLINE defaultNonceGen #-}
